==> lxqt-powermanagement-2.2.0.tar.xz: lxqt-powermanagement-2.2.0/src/translations/lxqt-powermanagement_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Stable</source>
        <translation>Ổn định</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>Đang xả pin</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>Sạc đầy</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>Đang sạc</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>Lithium ion</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>Lithium polymer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium sắt phosphat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>Axít chì</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>Niken cadmi</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>Niken hyđrua kim loại</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Không rõ</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Pin của Thiết bị kỹ thuật số hỗ trợ cá nhân</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Pin của Bộ lưu trữ điện dự phòng</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>Pin chính</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>Pin chuột</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>Pin bàn phím</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Pin bàn phím và chuột</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>Pin camera</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>Pin điện thoại</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>Pin màn hình</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>Pin không rõ</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln giờ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln phút</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation>còn lại %1</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation>đến khi đầy %1</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Hộp thoại</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Thông tin Pin</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Quản lý Năng lượng</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Nhiệt độ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Loại:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Tình trạng:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Thiết kế Năng lượng Đầy đủ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Năng lượng Đầy:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Năng lượng Hiện tại:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Tỉ lệ năng lượng:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Công nghệ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Hiệu điện thế:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Hãng:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.cpp" line="65"/>
        <source>Empty</source>
        <translation>Trống</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Không có pin!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt không thể tìm thấy được dữ liệu về bất kì pin nào - theo dõi đã bị tắt</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>Pin yếu!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %Ln second(s)</source>
        <translation>
            <numerusform>Sẽ tạm ngưng trong %Ln giây</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %Ln second(s)</source>
        <translation>
            <numerusform>Sẽ ngủ đông trong %Ln giây</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %Ln second(s)</source>
        <translation>
            <numerusform>Sẽ tắt nguồn trong %Ln giây</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LXQt::PowerProfiles</name>
    <message>
        <location filename="../PowerProfiles.cpp" line="38"/>
        <source>power-saver</source>
        <comment>power-profiles-daemon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="39"/>
        <source>balanced</source>
        <comment>power-profiles-daemon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="40"/>
        <source>performance</source>
        <comment>power-profiles-daemon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="69"/>
        <source>Power profile</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Hành động phím tắt nguồn</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Hành động phím tạm ngưng</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Hành động phím ngủ đông</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Quản lý Năng lượng</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Bạn đang chạy Quản lý Năng lượng LXQt lần đầu tiên.
Bạn có thể tùy chỉnh nó trong cài đặt... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Tùy chỉnh...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="70"/>
        <source>Configure</source>
        <translation>Tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="78"/>
        <source>30 minutes</source>
        <translation>30 phút</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="82"/>
        <source>1 hour</source>
        <translation>1 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="86"/>
        <source>2 hours</source>
        <translation>2 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="90"/>
        <source>3 hours</source>
        <translation>3 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="94"/>
        <source>4 hours</source>
        <translation>4 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="99"/>
        <source>Pause idleness checks</source>
        <translation>Tạm dừng kiểm tra trạng thái không hoạt động</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="107"/>
        <location filename="../trayicon.cpp" line="199"/>
        <source>About</source>
        <translation>Về</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="109"/>
        <source>Disable icon</source>
        <translation>Tắt biểu tượng</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="168"/>
        <source>Empty</source>
        <translation>Trống</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="200"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2025&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Quản lý Năng lượng LXQt &lt;/b&gt;&lt;br/&gt;  - Quản lý Năng lượng cho Môi trường Máy tính để bàn LXQt&lt;/p&gt;&lt;p&gt;  Tác giả:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - và những người khác từ dự án Razor và LXQt&lt;/p&gt;&lt;p&gt;  Bản quyền &amp;copy; 2012-2025&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="218"/>
        <source>LXQt Power Management info</source>
        <translation>Thông tin Quản lý Năng lượng LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="219"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Biểu tượng trên khay hệ thống của Quản lý Năng lượng LXQt có thể được bật (lại) trong &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="221"/>
        <source>Configure now</source>
        <translation>Tùy chỉnh ngay bây giờ</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_2.3.0.orig.tar.xz: lxqt-powermanagement-2.3.0/src/translations/lxqt-powermanagement_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Stable</source>
        <translation>Ổn định</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>Đang xả pin</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>Sạc đầy</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>Đang sạc</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>Lithium ion</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>Lithium polymer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium sắt phosphat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>Axít chì</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>Niken cadmi</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>Niken hyđrua kim loại</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Không rõ</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Pin của Thiết bị kỹ thuật số hỗ trợ cá nhân</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Pin của Bộ lưu trữ điện dự phòng</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>Pin chính</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>Pin chuột</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>Pin bàn phím</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Pin bàn phím và chuột</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>Pin camera</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>Pin điện thoại</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>Pin màn hình</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>Pin không rõ</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln giờ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln phút</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation>còn lại %1</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation>đến khi đầy %1</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Hộp thoại</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Thông tin Pin</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Quản lý Năng lượng</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Nhiệt độ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Loại:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Tình trạng:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Thiết kế Năng lượng Đầy đủ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Năng lượng Đầy:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Năng lượng Hiện tại:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Tỉ lệ năng lượng:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Công nghệ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Hiệu điện thế:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Hãng:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.cpp" line="65"/>
        <source>Empty</source>
        <translation>Trống</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Không có pin!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt không thể tìm thấy được dữ liệu về bất kì pin nào - theo dõi đã bị tắt</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>Pin yếu!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %Ln second(s)</source>
        <translation>
            <numerusform>Sẽ tạm ngưng trong %Ln giây</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %Ln second(s)</source>
        <translation>
            <numerusform>Sẽ ngủ đông trong %Ln giây</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %Ln second(s)</source>
        <translation>
            <numerusform>Sẽ tắt nguồn trong %Ln giây</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LXQt::PowerProfiles</name>
    <message>
        <location filename="../PowerProfiles.cpp" line="38"/>
        <source>power-saver</source>
        <comment>power-profiles-daemon</comment>
        <translation>tiết kiệm năng lượng</translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="39"/>
        <source>balanced</source>
        <comment>power-profiles-daemon</comment>
        <translation>cân bằng</translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="40"/>
        <source>performance</source>
        <comment>power-profiles-daemon</comment>
        <translation>hiệu năng cao</translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="69"/>
        <source>Power profile</source>
        <translation>Chế độ năng lượng</translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Hành động phím tắt nguồn</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Hành động phím tạm ngưng</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Hành động phím ngủ đông</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Quản lý Năng lượng</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Bạn đang chạy Quản lý Năng lượng LXQt lần đầu tiên.
Bạn có thể tùy chỉnh nó trong cài đặt... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Tùy chỉnh...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="70"/>
        <source>Configure</source>
        <translation>Tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="78"/>
        <source>30 minutes</source>
        <translation>30 phút</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="82"/>
        <source>1 hour</source>
        <translation>1 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="86"/>
        <source>2 hours</source>
        <translation>2 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="90"/>
        <source>3 hours</source>
        <translation>3 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="94"/>
        <source>4 hours</source>
        <translation>4 giờ</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="99"/>
        <source>Pause idleness checks</source>
        <translation>Tạm dừng kiểm tra trạng thái không hoạt động</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="107"/>
        <location filename="../trayicon.cpp" line="199"/>
        <source>About</source>
        <translation>Về</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="109"/>
        <source>Disable icon</source>
        <translation>Tắt biểu tượng</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="168"/>
        <source>Empty</source>
        <translation>Trống</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="200"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2025&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Quản lý Năng lượng LXQt &lt;/b&gt;&lt;br/&gt;  - Quản lý Năng lượng cho Môi trường Máy tính để bàn LXQt&lt;/p&gt;&lt;p&gt;  Tác giả:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - và những người khác từ dự án Razor và LXQt&lt;/p&gt;&lt;p&gt;  Bản quyền &amp;copy; 2012-2025&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="218"/>
        <source>LXQt Power Management info</source>
        <translation>Thông tin Quản lý Năng lượng LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="219"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Biểu tượng trên khay hệ thống của Quản lý Năng lượng LXQt có thể được bật (lại) trong &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="221"/>
        <source>Configure now</source>
        <translation>Tùy chỉnh ngay bây giờ</translation>
    </message>
</context>
</TS>
